"use strict";
// Copyright 2016-2018, Pulumi Corporation.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * configEnvKey is the environment variable key that the language plugin uses to set configuration values.
 */
const configEnvKey = "PULUMI_CONFIG";
const config = parseConfig();
/**
 * allConfig returns a copy of the full config map.
 */
function allConfig() {
    return Object.assign({}, config);
}
exports.allConfig = allConfig;
/**
 * setConfig sets a configuration variable.
 */
function setConfig(k, v) {
    config[cleanKey(k)] = v;
}
exports.setConfig = setConfig;
/**
 * getConfig returns a configuration variable's value or undefined if it is unset.
 */
function getConfig(k) {
    return config[k];
}
exports.getConfig = getConfig;
function parseConfig() {
    const parsedConfig = {};
    const envConfig = process.env[configEnvKey];
    if (envConfig) {
        const envObject = JSON.parse(envConfig);
        for (const k of Object.keys(envObject)) {
            parsedConfig[cleanKey(k)] = envObject[k];
        }
    }
    return parsedConfig;
}
/**
 * cleanKey takes a configuration key, and if it is of the form "<string>:config:<string>" removes
 * the ":config:" portion. Previously, our keys always had the string ":config:" in them, and we'd
 * like to remove it. However, the language host needs to continue to set it so we can be compatible
 * with older versions of our packages. Once we stop supporting older packages, we can change the
 * language host to not add this :config: thing and remove this function.
 */
function cleanKey(key) {
    const idx = key.indexOf(":");
    if (idx > 0 && key.startsWith("config:", idx + 1)) {
        return key.substring(0, idx) + ":" + key.substring(idx + 1 + "config:".length);
    }
    return key;
}
