"use strict";
// Copyright 2016-2018, Pulumi Corporation.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
const metadata_1 = require("../metadata");
const resource_1 = require("../resource");
const settings_1 = require("./settings");
/**
 * rootPulumiStackTypeName is the type name that should be used to construct the root component in the tree of Pulumi
 * resources allocated by a deployment.  This must be kept up to date with
 * `github.com/pulumi/pulumi/pkg/resource/stack.RootPulumiStackTypeName`.
 */
exports.rootPulumiStackTypeName = "pulumi:pulumi:Stack";
/**
 * runInPulumiStack creates a new Pulumi stack resource and executes the callback inside of it.  Any outputs
 * returned by the callback will be stored as output properties on this resulting Stack object.
 */
function runInPulumiStack(init) {
    const _ = new Stack(init);
}
exports.runInPulumiStack = runInPulumiStack;
class Stack extends resource_1.ComponentResource {
    constructor(init) {
        super(exports.rootPulumiStackTypeName, `${metadata_1.getProject()}-${metadata_1.getStack()}`);
        if (settings_1.getRootResource()) {
            throw new Error("Only one root Pulumi Stack may be active at once");
        }
        let outputs;
        try {
            settings_1.setRootResource(this); // install ourselves as the current root.
            outputs = init(); // run the init code.
        }
        finally {
            super.registerOutputs(outputs); // save the outputs for this component to whatever the init returned.
            // intentionally not removing the root resource because we want subsequent async turns to parent to it.
        }
    }
}
